@@ -1,7 +1,7 @@
 #! /bin/sh
 # This script discards all local changes and reload missing files
 echo "cvsdiscard: cleaning up ..."
-cvsu --ignore --find --types 'GM' --batch "rm -rf" "$@"
+cvsu --ignore --find --types 'GMO' --batch "rm -rf" "$@"
 test $? -eq 0 || exit 1
 echo "cvsdiscard: refetching missing files ..."
 cvsu --ignore --find --types 'U' --batch "cvs update" "$@"
